# Fedora package release versions are committed as versions in upstream
%define origrel 1

# Tests currently fail, so tests are disabled for now
# See https://github.com/xsuchy/rpmconf/issues/31
%bcond_with tests

Name:           rpmconf
Summary:        Tool to handle rpmnew and rpmsave files
Group:          System/Packaging
License:        GPLv3
Version:        1.1.3
Release:        %mkrel 1
URL:            http://wiki.github.com/xsuchy/rpmconf
Source0:        https://github.com/xsuchy/rpmconf/archive/%{name}-%{version}-%{origrel}.tar.gz
BuildArch:      noarch
BuildRequires:  docbook-utils
BuildRequires:  docbook-dtd31-sgml
BuildRequires:  python3-sphinx
BuildRequires:  python3-devel
BuildRequires:  python3-rpm

%if %{with tests}
BuildRequires:  python3-pylint
BuildRequires:  python3-six
%endif

Requires:       %{name}-base
Requires:       python3-%{name}
Requires:       python3-rpm

# mergetools
Suggests: diffuse
Suggests: kdiff3
Suggests: meld
Suggests: vim-X11
Suggests: vim-enhanced

%description
This tool search for .rpmnew, .rpmsave and .rpmorig
files and ask you what to do with them:
Keep current version, place back old version,
watch the diff or merge.

%package -n python3-rpmconf
Summary:        Python interface for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-rpmconf}

%description -n python3-rpmconf
Python interface for %{name}.

%package -n python3-rpmconf-doc
Summary:        Documentation of python interface for %{name}
Group:          Development/Python

%description -n python3-rpmconf-doc
Documentation generated from code of python3-rpmconf.

%package base
Summary:        Filesystem for %{name}
Group:          System/Packaging

%description base
Directory hierarchy for installation scripts,
which are handled by rpmconf.

%prep
%setup -q -n %{name}-%{name}-%{version}-%{origrel}

%build
%py3_build
docbook2man rpmconf.sgml
make -C docs html man

%install
%py3_install -- --install-scripts %{_sbindir}

install -D -m 644 rpmconf.8 %{buildroot}%{_mandir}/man8/rpmconf.8
install -D -m 644 docs/build/man/rpmconf.3 %{buildroot}%{_mandir}/man3/rpmconf.3
mkdir -p %{buildroot}%{_datadir}/rpmconf/

%if %{with tests}
%check
python3-pylint --reports=n %{buildroot}%{_sbindir}/rpmconf
python3-pylint --reports=n %{buildroot}%{python3_sitelib}/rpmconf/rpmconf.py
%endif

%files
%license LICENSE
%{_sbindir}/rpmconf
%{_mandir}/man8/rpmconf.8*

%files -n python3-rpmconf
%license LICENSE
%{python3_sitelib}/rpmconf/
%{python3_sitelib}/rpmconf-*.egg-info
%{_mandir}/man3/rpmconf.3*

%files -n python3-rpmconf-doc
%license LICENSE
%doc docs/build/html/

%files base
%dir %{_datadir}/rpmconf



%changelog
* Wed Dec 30 2020 luigiwalser <luigiwalser> 1.1.3-1.mga8
+ Revision: 1665491
- 1.1.3

* Sat Dec 05 2020 luigiwalser <luigiwalser> 1.1.2-1.mga8
+ Revision: 1652969
- 1.1.2

* Fri Oct 30 2020 wally <wally> 1.1.1-1.mga8
+ Revision: 1640685
- new version 1.1.1

* Fri Oct 30 2020 joequant <joequant> 1.0.16-7.mga8
+ Revision: 1640677
- fix build

* Sun Feb 16 2020 umeabot <umeabot> 1.0.16-6.mga8
+ Revision: 1533955
- Mageia 8 Mass Rebuild

* Wed Sep 25 2019 wally <wally> 1.0.16-5.mga8
+ Revision: 1445883
- rebuild for python3.8

* Sat Jan 05 2019 wally <wally> 1.0.16-4.mga7
+ Revision: 1349819
- rebuild for python3.7

* Fri Sep 21 2018 umeabot <umeabot> 1.0.16-3.mga7
+ Revision: 1290773
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 1.0.16-2.mga7
+ Revision: 1135713
- Rebuild for python 3.6

* Sun Jan 24 2016 ngompa <ngompa> 1.0.16-1.mga6
+ Revision: 926825
- Update to 1.0.16

* Mon Nov 23 2015 ngompa <ngompa> 1.0.13-2.mga6
+ Revision: 905068
- Import rpmconf into Mageia


* Sun Nov 15 2015 Neal Gompa <ngompa13{%%}gmail{*}com> - 1.0.13-2
- Port to Mageia

* Fri Nov 13 2015 Miroslav Suchý <msuchy@redhat.com> 1.0.13-1
- 1278134 - do TB when somebody remove file under our hand

* Tue Jun 30 2015 Miroslav Suchý <msuchy@redhat.com> 1.0.12-1
- disable pylint warning

* Tue Jun 30 2015 Miroslav Suchý <msuchy@redhat.com> 1.0.11-1
- disable pylint warning

* Tue Jun 30 2015 Miroslav Suchý <miroslav@suchy.cz> 1.0.10-1
- 1236722 - other method for stdin flush and handle Ctrl+C correctly

* Mon Jun 01 2015 Miroslav Suchý <msuchy@redhat.com> 1.0.9-1
- pylint: let the logger expand params
- use soft deps

* Mon Jun 01 2015 Miroslav Suchý <msuchy@redhat.com> 1.0.8-1
- 1226591 - do not flush stdin, when it is not TTY
- BR python3-six
- minor fixes
- use RPM Python API to get package name of file

* Mon Jan 12 2015 Miroslav Suchý <miroslav@suchy.cz> 1.0.7-1
- correctly reference tar.gz
- add / before usr/bin
- remove superfluous changelog line

* Fri Jan 09 2015 Miroslav Suchý <miroslav@suchy.cz> 1.0.6-1
- let tito bump up version in docs/source/conf.py

* Thu Jan 08 2015 Miroslav Suchý <miroslav@suchy.cz> 1.0.5-1
- add -doc subpackage
- mark LICENSE as %%license
- Split to python class and CLI
- use rpm python api to get version

* Sun Nov 23 2014 Miroslav Suchý <msuchy@redhat.com> 1.0.4-1
- add BR rpm-python3

* Sun Nov 23 2014 Miroslav Suchý <miroslav@suchy.cz> 1.0.3-1
- Allow specification of a custom merge type via an environment variable,
  $MERGE
- do not remove files on those merge tools, which does not return correct exit
  code
- make pylint run mandatory
- skip /var/lib/mock when --clean
- use rpm bindings to find configfiles
- use filecmp instead of subprocessed diff

* Tue Nov 04 2014 Miroslav Suchý <msuchy@redhat.com> 1.0.2-1
- require rpm-python3

* Wed Oct 29 2014 Miroslav Suchý <msuchy@redhat.com> 1.0.1-1
- migrate to python3
- handle symlinks correctly

* Thu Oct 02 2014 Miroslav Suchý 0.3.7-1
- when there is no error return 0

* Sun Jan 12 2014 Miroslav Suchý <miroslav@suchy.cz> 0.3.6-1
- add non-interactive --diff mode
- remove some white space in NAME section
- remove garbage from man page
- rpmconf-base should not require rpmconf

* Thu Jul 25 2013 Miroslav Suchý <msuchy@redhat.com> 0.3.5-1
- add ability to configure packages
- replace old macro RPM_BUILD_ROOT
- create subpackage -base which will own /usr/share/rpmconf
- document ability to handle app configuration

* Mon Jul 15 2013 Miroslav Suchý <miroslav@suchy.cz>
- When overwriting the current file with an .rpmnew/.rpmsave file, check that
  the copy worked before removing the source file.
- Skip deleting files if user input could not be read.
- fix few spelling typos

* Fri Jul 08 2011 Miroslav Suchý 0.3.3-1
- Revert "change download location to github magic url"

* Fri Jul 08 2011 Miroslav Suchý 0.3.2-1
- change download location to github magic url

* Fri Jul 08 2011 Miroslav Suchý 0.3.1-1
- bump up version
- add warning about --debug position sensitivity
- scan /usr during --clean
- introduce new option -Z to print SELinux context of old and new file
- do not dereference links
- allow another option : skip the current config file and go to the next one
- show config file dates
- we do not need perl
- --clean - Find and delete orphaned .rpmnew and .rpmsave files.
- fix spelling error

* Mon Feb 22 2010 Miroslav Suchy <msuchy@redhat.com> 0.2.2-1
- 567318 - fix syntax error
- add diffuse as merge frontend

* Thu Jan  7 2010 Miroslav Suchy <msuchy@redhat.com> 0.2.1-1
- implement merging of files using vimdiff, gvimdiff, meld,
  and kdiff3
- added command line option --version
- added command line option --debug
- fix build requires on Mandriva

* Mon Aug 31 2009 Miroslav Suchy <msuchy@redhat.com> 0.1.8-1
- fix copy and past typo

* Fri Aug 28 2009 Miroslav Suchy <msuchy@redhat.com> 0.1.7-1
- add support for handling .rpmorig
- 513794 - localisation problem
- add support for suspending script

* Fri Jul 17 2009 Miroslav Suchy <msuchy@redhat.com> 0.1.6-1
- addressed fedora package review notes (#7)

* Thu Jul 16 2009 Miroslav Suchy <msuchy@redhat.com> 0.1.5-1
- addressed fedora package review notes

* Thu Jul 16 2009 Miroslav Suchy <msuchy@redhat.com> 0.1.3-1
- initial version

